<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('booking_status');

// 记录访问日志
record_log('访问房态管理页面');

// 设置默认查询日期范围
$today = date('Y-m-d');
$default_start_date = isset($_GET['start_date']) ? $_GET['start_date'] : $today;
$default_end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d', strtotime('+7 days'));

// 获取所有房型
try {
    $stmt = $pdo->query("SELECT id, type_name, description FROM room_types WHERE status = 1 ORDER BY id");
    $room_types = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取房型列表失败：' . $e->getMessage();
    $room_types = [];
}

// 获取所有房间
try {
    $stmt = $pdo->query("
        SELECT r.id, r.room_number, r.room_type_id, r.status, rt.type_name 
        FROM room_info r
        JOIN room_types rt ON r.room_type_id = rt.id
        ORDER BY r.room_type_id, r.room_number
    ");
    $rooms = $stmt->fetchAll();

    // 按房型分组房间
    $rooms_by_type = [];
    foreach ($rooms as $room) {
        if (!isset($rooms_by_type[$room['room_type_id']])) {
            $rooms_by_type[$room['room_type_id']] = [];
        }
        $rooms_by_type[$room['room_type_id']][] = $room;
    }
} catch (PDOException $e) {
    $error = '获取房间列表失败：' . $e->getMessage();
    $rooms = [];
    $rooms_by_type = [];
}

// 获取日期范围内的预订信息
try {
    $stmt = $pdo->prepare("
        SELECT bo.id, bo.booking_no, bo.guest_name, bo.arrival_date, bo.departure_date, 
               bo.status, bo.room_type_id, bo.room_count
        FROM booking_orders bo
        WHERE bo.status IN (1, 2, 4) 
        AND (
            (bo.arrival_date BETWEEN ? AND ?) OR
            (bo.departure_date BETWEEN ? AND ?) OR
            (bo.arrival_date <= ? AND bo.departure_date >= ?)
        )
        ORDER BY bo.arrival_date, bo.id
    ");

    $stmt->execute([
        $default_start_date,
        $default_end_date,
        $default_start_date,
        $default_end_date,
        $default_start_date,
        $default_end_date
    ]);

    $bookings = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取预订信息失败：' . $e->getMessage();
    $bookings = [];
}

// 生成日期范围
$start_date = new DateTime($default_start_date);
$end_date = new DateTime($default_end_date);
$date_range = [];
$current_date = clone $start_date;

while ($current_date <= $end_date) {
    $date_range[] = $current_date->format('Y-m-d');
    $current_date->modify('+1 day');
}

// 计算每个房型每天的可用房间数和预订房间数
$availability = [];
foreach ($room_types as $room_type) {
    $room_type_id = $room_type['id'];
    $availability[$room_type_id] = [];

    // 获取该房型的总房间数
    $total_rooms = isset($rooms_by_type[$room_type_id]) ? count($rooms_by_type[$room_type_id]) : 0;

    foreach ($date_range as $date) {
        $availability[$room_type_id][$date] = [
            'total' => $total_rooms,
            'booked' => 0,
            'available' => $total_rooms,
            'bookings' => []
        ];
    }
}

// 计算预订的房间数
foreach ($bookings as $booking) {
    $room_type_id = $booking['room_type_id'];
    $arrival = new DateTime($booking['arrival_date']);
    $departure = new DateTime($booking['departure_date']);
    $room_count = $booking['room_count'];

    // 标记预订期间的每一天
    $booking_date = clone $arrival;
    while ($booking_date < $departure) { // 不包括离店日
        $date_str = $booking_date->format('Y-m-d');
        if (isset($availability[$room_type_id][$date_str])) {
            $availability[$room_type_id][$date_str]['booked'] += $room_count;
            $availability[$room_type_id][$date_str]['available'] = $availability[$room_type_id][$date_str]['total'] - $availability[$room_type_id][$date_str]['booked'];
            $availability[$room_type_id][$date_str]['bookings'][] = [
                'id' => $booking['id'],
                'booking_no' => $booking['booking_no'],
                'guest_name' => $booking['guest_name'],
                'status' => $booking['status']
            ];
        }
        $booking_date->modify('+1 day');
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
    <style>
        .calendar-container {
            overflow-x: auto;
        }

        .room-calendar {
            border-collapse: collapse;
            min-width: 100%;
        }

        .room-calendar th,
        .room-calendar td {
            border: 1px solid #ddd;
            padding: 8px;
            text-align: center;
            min-width: 100px;
        }

        .room-calendar .room-type-header {
            background-color: #f8f9fa;
            font-weight: bold;
            text-align: left;
        }

        .room-calendar .date-header {
            background-color: #e9ecef;
        }

        .room-calendar .weekend {
            background-color: #f8f9fa;
        }

        .room-calendar .today {
            background-color: #e8f4f8;
            font-weight: bold;
        }

        .availability-good {
            background-color: #d4edda;
            color: #155724;
        }

        .availability-warning {
            background-color: #fff3cd;
            color: #856404;
        }

        .availability-danger {
            background-color: #f8d7da;
            color: #721c24;
        }

        .booking-pill {
            display: inline-block;
            padding: 2px 5px;
            margin: 2px;
            border-radius: 3px;
            font-size: 0.8em;
            background-color: #007bff;
            color: white;
            cursor: pointer;
        }

        .booking-pill.status-1 {
            background-color: #ffc107;
            /* 待确认 */
        }

        .booking-pill.status-2 {
            background-color: #28a745;
            /* 已确认 */
        }

        .booking-pill.status-4 {
            background-color: #17a2b8;
            /* 已入住 */
        }
    </style>
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>房态管理</h2>
            <div class="breadcrumb">
                <a href="index.php">预订管理</a> &gt; 房态管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <!-- 日期范围选择 -->
            <div class="filter-form">
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="start_date">开始日期：</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo $default_start_date; ?>">
                        </div>
                        <div class="filter-item">
                            <label for="end_date">结束日期：</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo $default_end_date; ?>">
                        </div>
                        <div class="filter-item" style="flex: 0 0 auto; align-self: flex-end;">
                            <button type="submit" class="btn btn-primary">查看房态</button>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 房态日历 -->
            <h3>房态日历（<?php echo $default_start_date; ?> 至 <?php echo $default_end_date; ?>）</h3>
            <div class="calendar-container">
                <table class="room-calendar">
                    <thead>
                        <tr>
                            <th>房型</th>
                            <?php foreach ($date_range as $date): ?>
                                <?php
                                $date_obj = new DateTime($date);
                                $is_weekend = ($date_obj->format('N') >= 6); // 6, 7 是周六日
                                $is_today = ($date == date('Y-m-d'));
                                $class = $is_today ? 'today' : ($is_weekend ? 'weekend' : '');
                                ?>
                                <th class="date-header <?php echo $class; ?>">
                                    <?php echo $date_obj->format('m-d'); ?><br>
                                    <small><?php echo ['日', '一', '二', '三', '四', '五', '六'][$date_obj->format('w')]; ?></small>
                                </th>
                            <?php endforeach; ?>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($room_types as $room_type): ?>
                            <tr>
                                <td class="room-type-header">
                                    <?php echo $room_type['type_name']; ?><br>
                                    <small>总数: <?php echo isset($rooms_by_type[$room_type['id']]) ? count($rooms_by_type[$room_type['id']]) : 0; ?></small>
                                </td>
                                <?php foreach ($date_range as $date): ?>
                                    <?php
                                    $available = $availability[$room_type['id']][$date]['available'];
                                    $total = $availability[$room_type['id']][$date]['total'];
                                    $booked = $availability[$room_type['id']][$date]['booked'];
                                    $percent = $total > 0 ? ($booked / $total) * 100 : 0;

                                    if ($percent < 70) {
                                        $class = 'availability-good';
                                    } elseif ($percent < 90) {
                                        $class = 'availability-warning';
                                    } else {
                                        $class = 'availability-danger';
                                    }
                                    ?>
                                    <td class="<?php echo $class; ?>">
                                        <div class="availability">
                                            <strong><?php echo $available; ?></strong> 可用
                                            <br>
                                            <span><?php echo $booked; ?> 已订</span>
                                        </div>
                                        <?php if (!empty($availability[$room_type['id']][$date]['bookings'])): ?>
                                            <div class="bookings">
                                                <?php foreach ($availability[$room_type['id']][$date]['bookings'] as $booking): ?>
                                                    <div class="booking-pill status-<?php echo $booking['status']; ?>"
                                                        title="<?php echo $booking['guest_name']; ?> - <?php echo $booking['booking_no']; ?>"
                                                        onclick="location.href='order.php?view=<?php echo $booking['id']; ?>'">
                                                        <?php echo mb_substr($booking['guest_name'], 0, 2, 'UTF-8'); ?>
                                                    </div>
                                                <?php endforeach; ?>
                                            </div>
                                        <?php endif; ?>
                                    </td>
                                <?php endforeach; ?>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>

            <div class="info-box" style="margin-top: 20px;">
                <h3>图例说明</h3>
                <div style="display: flex; gap: 20px; flex-wrap: wrap;">
                    <div>
                        <span class="availability-good" style="padding: 2px 6px;">绿色</span> - 充足房间 (≥30%)
                    </div>
                    <div>
                        <span class="availability-warning" style="padding: 2px 6px;">黄色</span> - 有限房间 (10-30%)
                    </div>
                    <div>
                        <span class="availability-danger" style="padding: 2px 6px;">红色</span> - 即将满房 (<10%)
                            </div>
                            <div>
                                <span class="booking-pill status-1">AB</span> - 待确认预订
                            </div>
                            <div>
                                <span class="booking-pill status-2">CD</span> - 已确认预订
                            </div>
                            <div>
                                <span class="booking-pill status-4">EF</span> - 已入住客人
                            </div>
                    </div>
                    <p style="margin-top: 10px;">点击客人标签可以查看预订详情。</p>
                </div>
            </div>
        </div>
</body>

</html>