<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('finance_report');

// 记录访问日志
record_log('访问财务报表页面');

// 获取筛选条件
$report_type = isset($_GET['report_type']) ? $_GET['report_type'] : 'daily';
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-30 days'));
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');
$payment_method = isset($_GET['payment_method']) ? intval($_GET['payment_method']) : 0;

// 根据报表类型设置时间分组格式
$group_format = '';
$date_format = '';
switch ($report_type) {
    case 'monthly':
        $group_format = '%Y-%m';
        $date_format = 'Y-m';
        break;
    case 'yearly':
        $group_format = '%Y';
        $date_format = 'Y';
        break;
    case 'daily':
    default:
        $group_format = '%Y-%m-%d';
        $date_format = 'Y-m-d';
        $report_type = 'daily'; // 确保默认值正确
        break;
}

// 构建查询条件
$where_clauses = ["payment_time BETWEEN ? AND ?"];
$params = [$start_date . ' 00:00:00', $end_date . ' 23:59:59'];

if ($payment_method > 0) {
    $where_clauses[] = "payment_method = ?";
    $params[] = $payment_method;
}

$where_sql = implode(" AND ", $where_clauses);

// 获取收入报表数据
try {
    $sql = "
        SELECT 
            DATE_FORMAT(payment_time, '{$group_format}') as period,
            SUM(CASE WHEN type = 1 AND status = 1 THEN amount ELSE 0 END) as income,
            SUM(CASE WHEN type = 2 AND status = 2 THEN amount ELSE 0 END) as expense,
            SUM(CASE WHEN type = 1 AND status = 1 THEN amount ELSE 0 END) - 
            SUM(CASE WHEN type = 2 AND status = 2 THEN amount ELSE 0 END) as net_income,
            COUNT(CASE WHEN type = 1 AND status = 1 THEN 1 ELSE NULL END) as income_count,
            COUNT(CASE WHEN type = 2 AND status = 2 THEN 1 ELSE NULL END) as expense_count
        FROM finance_payments
        WHERE {$where_sql}
        GROUP BY period
        ORDER BY period ASC
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $reports = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取报表数据失败：' . $e->getMessage();
    $reports = [];
}

// 获取按支付方式统计的数据
try {
    $sql = "
        SELECT 
            payment_method,
            SUM(CASE WHEN type = 1 AND status = 1 THEN amount ELSE 0 END) as income,
            SUM(CASE WHEN type = 2 AND status = 2 THEN amount ELSE 0 END) as expense,
            COUNT(CASE WHEN type = 1 AND status = 1 THEN 1 ELSE NULL END) as income_count,
            COUNT(CASE WHEN type = 2 AND status = 2 THEN 1 ELSE NULL END) as expense_count
        FROM finance_payments
        WHERE {$where_sql}
        GROUP BY payment_method
        ORDER BY payment_method ASC
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $payment_method_stats = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取支付方式统计失败：' . $e->getMessage();
    $payment_method_stats = [];
}

// 计算总计数据
$total_income = 0;
$total_expense = 0;
$total_net_income = 0;
$total_income_count = 0;
$total_expense_count = 0;

foreach ($reports as $report) {
    $total_income += $report['income'];
    $total_expense += $report['expense'];
    $total_net_income += $report['net_income'];
    $total_income_count += $report['income_count'];
    $total_expense_count += $report['expense_count'];
}

// 支付方式列表
$payment_methods = [
    1 => '现金',
    2 => '信用卡',
    3 => '微信',
    4 => '支付宝',
    5 => '银行转账'
];

// 获取收入TOP5订单
try {
    $stmt = $pdo->prepare("
        SELECT p.*, 
               CASE 
                   WHEN p.booking_id IS NOT NULL THEN b.booking_no
                   WHEN p.checkin_id IS NOT NULL THEN c.checkin_no
                   ELSE NULL
               END AS order_no,
               CASE 
                   WHEN p.booking_id IS NOT NULL THEN b.guest_name
                   WHEN p.checkin_id IS NOT NULL THEN c.guest_name
                   ELSE NULL
               END AS guest_name
        FROM finance_payments p
        LEFT JOIN booking_orders b ON p.booking_id = b.id
        LEFT JOIN checkin_orders c ON p.checkin_id = c.id
        WHERE p.type = 1 AND p.status = 1 AND {$where_sql}
        ORDER BY p.amount DESC
        LIMIT 5
    ");
    $stmt->execute($params);
    $top_income_orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取TOP5收入订单失败：' . $e->getMessage();
    $top_income_orders = [];
}

// 获取退款TOP5订单
try {
    $stmt = $pdo->prepare("
        SELECT p.*, 
               CASE 
                   WHEN p.booking_id IS NOT NULL THEN b.booking_no
                   WHEN p.checkin_id IS NOT NULL THEN c.checkin_no
                   ELSE NULL
               END AS order_no,
               CASE 
                   WHEN p.booking_id IS NOT NULL THEN b.guest_name
                   WHEN p.checkin_id IS NOT NULL THEN c.guest_name
                   ELSE NULL
               END AS guest_name
        FROM finance_payments p
        LEFT JOIN booking_orders b ON p.booking_id = b.id
        LEFT JOIN checkin_orders c ON p.checkin_id = c.id
        WHERE p.type = 2 AND p.status = 2 AND {$where_sql}
        ORDER BY p.amount DESC
        LIMIT 5
    ");
    $stmt->execute($params);
    $top_expense_orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取TOP5退款订单失败：' . $e->getMessage();
    $top_expense_orders = [];
}

// 生成报表标题
$report_title = '';
switch ($report_type) {
    case 'monthly':
        $report_title = '月度财务报表';
        break;
    case 'yearly':
        $report_title = '年度财务报表';
        break;
    case 'daily':
    default:
        $report_title = '日常财务报表';
        break;
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>财务报表</title>
    <link rel="stylesheet" href="../style.css">
    <style>
        .summary-box {
            display: flex;
            flex-wrap: wrap;
            gap: 20px;
            margin-bottom: 20px;
        }

        .summary-item {
            flex: 1;
            min-width: 200px;
            background: #f8f9fa;
            padding: 15px;
            border-radius: 4px;
            border: 1px solid #ddd;
            text-align: center;
        }

        .summary-label {
            display: block;
            font-weight: bold;
            margin-bottom: 5px;
            color: #666;
        }

        .summary-value {
            display: block;
            font-size: 24px;
            font-weight: bold;
            color: #4CAF50;
        }

        .summary-value.expense {
            color: #dc3545;
        }

        .tab-container {
            margin-bottom: 20px;
        }

        .tab-buttons {
            display: flex;
            border-bottom: 1px solid #ddd;
            margin-bottom: 15px;
        }

        .tab-button {
            padding: 8px 16px;
            background: #f8f9fa;
            border: 1px solid #ddd;
            border-bottom: none;
            margin-right: 5px;
            border-radius: 4px 4px 0 0;
            cursor: pointer;
        }

        .tab-button.active {
            background: #4CAF50;
            color: white;
            border-color: #4CAF50;
        }

        .tabs {
            margin-top: 20px;
        }

        .tab-content {
            display: none;
        }

        .tab-content.active {
            display: block;
        }

        .chart-container {
            width: 100%;
            height: 300px;
            margin-bottom: 20px;
        }

        .status-warning {
            color: #ff9900;
        }
    </style>
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>财务报表</h2>
            <div class="breadcrumb">
                <a href="index.php">财务管理</a> &gt; 财务报表
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="report_type">报表类型：</label>
                            <select id="report_type" name="report_type">
                                <option value="daily" <?php echo $report_type == 'daily' ? 'selected' : ''; ?>>日报表</option>
                                <option value="monthly" <?php echo $report_type == 'monthly' ? 'selected' : ''; ?>>月报表</option>
                                <option value="yearly" <?php echo $report_type == 'yearly' ? 'selected' : ''; ?>>年报表</option>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="start_date">开始日期：</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo $start_date; ?>">
                        </div>
                        <div class="filter-item">
                            <label for="end_date">结束日期：</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo $end_date; ?>">
                        </div>
                    </div>
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="payment_method">支付方式：</label>
                            <select id="payment_method" name="payment_method">
                                <option value="0">全部</option>
                                <?php foreach ($payment_methods as $key => $method): ?>
                                    <option value="<?php echo $key; ?>" <?php echo $payment_method == $key ? 'selected' : ''; ?>><?php echo $method; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="filter-buttons">
                            <button type="submit" class="btn btn-primary">生成报表</button>
                            <a href="report.php" class="btn btn-secondary">重置</a>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 报表标题 -->
            <h3><?php echo $report_title; ?> (<?php echo $start_date; ?> 至 <?php echo $end_date; ?>)</h3>

            <!-- 数据概览 -->
            <div class="summary-box">
                <div class="summary-item">
                    <span class="summary-label">总收入</span>
                    <span class="summary-value">￥<?php echo number_format($total_income, 2); ?></span>
                    <span>(<?php echo $total_income_count; ?>笔)</span>
                </div>
                <div class="summary-item">
                    <span class="summary-label">总支出</span>
                    <span class="summary-value expense">￥<?php echo number_format($total_expense, 2); ?></span>
                    <span>(<?php echo $total_expense_count; ?>笔)</span>
                </div>
                <div class="summary-item">
                    <span class="summary-label">净收入</span>
                    <span class="summary-value <?php echo $total_net_income < 0 ? 'expense' : ''; ?>">￥<?php echo number_format($total_net_income, 2); ?></span>
                </div>
            </div>

            <!-- 主要内容标签页 -->
            <div class="tab-container">
                <div class="tab-buttons">
                    <div class="tab-button active" onclick="switchTab('period-report')">时间维度报表</div>
                    <div class="tab-button" onclick="switchTab('payment-method-report')">支付方式统计</div>
                    <div class="tab-button" onclick="switchTab('top-orders')">金额TOP5</div>
                </div>

                <div class="tabs">
                    <!-- 时间维度报表 -->
                    <div class="tab-content active" id="period-report">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>时间周期</th>
                                    <th>收入金额(元)</th>
                                    <th>收入笔数</th>
                                    <th>支出金额(元)</th>
                                    <th>支出笔数</th>
                                    <th>净收入(元)</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (count($reports) > 0): ?>
                                    <?php foreach ($reports as $report): ?>
                                        <tr>
                                            <td><?php echo $report['period']; ?></td>
                                            <td><?php echo number_format($report['income'], 2); ?></td>
                                            <td><?php echo $report['income_count']; ?></td>
                                            <td><?php echo number_format($report['expense'], 2); ?></td>
                                            <td><?php echo $report['expense_count']; ?></td>
                                            <td class="<?php echo $report['net_income'] < 0 ? 'status-inactive' : 'status-active'; ?>">
                                                <?php echo number_format($report['net_income'], 2); ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <tr>
                                        <td colspan="6" class="text-center">暂无报表数据</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                            <tfoot>
                                <tr>
                                    <th>总计</th>
                                    <th><?php echo number_format($total_income, 2); ?></th>
                                    <th><?php echo $total_income_count; ?></th>
                                    <th><?php echo number_format($total_expense, 2); ?></th>
                                    <th><?php echo $total_expense_count; ?></th>
                                    <th class="<?php echo $total_net_income < 0 ? 'status-inactive' : 'status-active'; ?>">
                                        <?php echo number_format($total_net_income, 2); ?>
                                    </th>
                                </tr>
                            </tfoot>
                        </table>
                    </div>

                    <!-- 支付方式统计 -->
                    <div class="tab-content" id="payment-method-report">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>支付方式</th>
                                    <th>收入金额(元)</th>
                                    <th>收入笔数</th>
                                    <th>支出金额(元)</th>
                                    <th>支出笔数</th>
                                    <th>净收入(元)</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (count($payment_method_stats) > 0): ?>
                                    <?php foreach ($payment_method_stats as $stat): ?>
                                        <tr>
                                            <td><?php echo isset($payment_methods[$stat['payment_method']]) ? $payment_methods[$stat['payment_method']] : '未知'; ?></td>
                                            <td><?php echo number_format($stat['income'], 2); ?></td>
                                            <td><?php echo $stat['income_count']; ?></td>
                                            <td><?php echo number_format($stat['expense'], 2); ?></td>
                                            <td><?php echo $stat['expense_count']; ?></td>
                                            <td class="<?php echo ($stat['income'] - $stat['expense']) < 0 ? 'status-inactive' : 'status-active'; ?>">
                                                <?php echo number_format($stat['income'] - $stat['expense'], 2); ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <tr>
                                        <td colspan="6" class="text-center">暂无统计数据</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>

                    <!-- TOP5订单 -->
                    <div class="tab-content" id="top-orders">
                        <h4>收入金额TOP5</h4>
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>支付单号</th>
                                    <th>关联订单</th>
                                    <th>客人</th>
                                    <th>金额(元)</th>
                                    <th>支付方式</th>
                                    <th>支付时间</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (count($top_income_orders) > 0): ?>
                                    <?php foreach ($top_income_orders as $order): ?>
                                        <tr>
                                            <td><?php echo $order['payment_no']; ?></td>
                                            <td><?php echo $order['order_no'] ?: '-'; ?></td>
                                            <td><?php echo $order['guest_name'] ?: '-'; ?></td>
                                            <td class="status-active"><?php echo number_format($order['amount'], 2); ?></td>
                                            <td><?php echo isset($payment_methods[$order['payment_method']]) ? $payment_methods[$order['payment_method']] : '未知'; ?></td>
                                            <td><?php echo date('Y-m-d H:i', strtotime($order['payment_time'])); ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <tr>
                                        <td colspan="6" class="text-center">暂无收入数据</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>

                        <h4>退款金额TOP5</h4>
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>退款单号</th>
                                    <th>关联订单</th>
                                    <th>客人</th>
                                    <th>金额(元)</th>
                                    <th>退款方式</th>
                                    <th>退款时间</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (count($top_expense_orders) > 0): ?>
                                    <?php foreach ($top_expense_orders as $order): ?>
                                        <tr>
                                            <td><?php echo $order['payment_no']; ?></td>
                                            <td><?php echo $order['order_no'] ?: '-'; ?></td>
                                            <td><?php echo $order['guest_name'] ?: '-'; ?></td>
                                            <td class="status-inactive"><?php echo number_format($order['amount'], 2); ?></td>
                                            <td><?php echo isset($payment_methods[$order['payment_method']]) ? $payment_methods[$order['payment_method']] : '未知'; ?></td>
                                            <td><?php echo date('Y-m-d H:i', strtotime($order['payment_time'])); ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <tr>
                                        <td colspan="6" class="text-center">暂无退款数据</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>

            <!-- 报表操作按钮 -->
            <div class="action-bar">
                <a href="javascript:window.print();" class="btn btn-primary">打印报表</a>
                <a href="report.php?export=1&report_type=<?php echo $report_type; ?>&start_date=<?php echo $start_date; ?>&end_date=<?php echo $end_date; ?>&payment_method=<?php echo $payment_method; ?>" class="btn btn-success">导出Excel</a>
            </div>
        </div>
    </div>

    <script>
        function switchTab(tabId) {
            // 隐藏所有标签页内容
            var tabContents = document.getElementsByClassName('tab-content');
            for (var i = 0; i < tabContents.length; i++) {
                tabContents[i].classList.remove('active');
            }

            // 重置所有标签按钮样式
            var tabButtons = document.getElementsByClassName('tab-button');
            for (var i = 0; i < tabButtons.length; i++) {
                tabButtons[i].classList.remove('active');
            }

            // 显示选中的标签页内容
            document.getElementById(tabId).classList.add('active');

            // 设置选中的标签按钮样式
            var activeButton = event.currentTarget;
            activeButton.classList.add('active');
        }

        // 根据报表类型自动调整日期选择器
        document.getElementById('report_type').addEventListener('change', function() {
            var reportType = this.value;
            var startDateField = document.getElementById('start_date');
            var endDateField = document.getElementById('end_date');

            var today = new Date();
            var startDate = new Date(today);

            if (reportType === 'yearly') {
                startDate.setFullYear(today.getFullYear() - 3);
                startDate.setMonth(0);
                startDate.setDate(1);
            } else if (reportType === 'monthly') {
                startDate.setMonth(today.getMonth() - 11);
                startDate.setDate(1);
            } else {
                startDate.setDate(today.getDate() - 30);
            }

            startDateField.value = startDate.toISOString().split('T')[0];
            endDateField.value = today.toISOString().split('T')[0];
        });
    </script>
</body>

</html>