<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('room');

// 记录访问日志
record_log('访问客房维修管理页面');

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加维修任务
    if ($_POST['action'] == 'add') {
        $room_id = isset($_POST['room_id']) ? intval($_POST['room_id']) : 0;
        $issue_type = isset($_POST['issue_type']) ? trim($_POST['issue_type']) : '';
        $issue_desc = isset($_POST['issue_desc']) ? trim($_POST['issue_desc']) : '';
        $priority = isset($_POST['priority']) ? intval($_POST['priority']) : 1;
        $maintainer_id = isset($_POST['maintainer_id']) ? trim($_POST['maintainer_id']) : null;

        if ($room_id <= 0 || empty($issue_type) || empty($issue_desc)) {
            $error = '请填写所有必填字段！';
        } else {
            try {
                // 获取房间号用于日志记录
                $stmt = $pdo->prepare("SELECT room_number FROM room_info WHERE id = ?");
                $stmt->execute([$room_id]);
                $room = $stmt->fetch();

                if (!$room) {
                    $error = '选择的房间不存在！';
                } else {
                    $stmt = $pdo->prepare("
                        INSERT INTO room_maintenance (
                            room_id, issue_type, issue_desc, status, reporter_id, 
                            maintainer_id, report_time
                        ) VALUES (?, ?, ?, ?, ?, ?, NOW())
                    ");
                    $result = $stmt->execute([
                        $room_id,
                        $issue_type,
                        $issue_desc,
                        1, // 1: 待处理
                        isset($_SESSION['user_id']) ? $_SESSION['user_id'] : null,
                        $maintainer_id
                    ]);

                    if ($result) {
                        record_log("为房间 {$room['room_number']} 添加维修任务：{$issue_type}");

                        // 如果维修问题严重，更新房间状态为维修中
                        $critical_issues = ['水电', '结构', '安全'];
                        if (in_array($issue_type, $critical_issues)) {
                            try {
                                $stmt = $pdo->prepare("UPDATE room_info SET status = 5 WHERE id = ?");
                                $stmt->execute([$room_id]);
                                record_log("房间 {$room['room_number']} 状态已更新为维修中");
                            } catch (PDOException $e) {
                                // 记录错误但不中断流程
                                error_log("更新房间状态失败：" . $e->getMessage());
                            }
                        }

                        $success = '维修任务添加成功！';
                    } else {
                        $error = '维修任务添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 更新维修任务状态
    elseif ($_POST['action'] == 'update_status') {
        $task_id = isset($_POST['task_id']) ? intval($_POST['task_id']) : 0;
        $new_status = isset($_POST['status']) ? intval($_POST['status']) : 0;
        $completion_notes = isset($_POST['completion_notes']) ? trim($_POST['completion_notes']) : '';

        if ($task_id <= 0 || $new_status <= 0 || $new_status > 3) {
            $error = '任务ID和状态必须提供且有效！';
        } else {
            try {
                // 获取当前任务信息用于日志记录
                $stmt = $pdo->prepare("
                    SELECT m.*, r.room_number 
                    FROM room_maintenance m
                    JOIN room_info r ON m.room_id = r.id
                    WHERE m.id = ?
                ");
                $stmt->execute([$task_id]);
                $task = $stmt->fetch();

                if (!$task) {
                    $error = '维修任务不存在！';
                } else {
                    // 根据新状态决定是否设置完成时间
                    $complete_time = ($new_status == 3) ? 'complete_time = NOW(),' : '';

                    // 更新维修员ID（如果处理中且未分配）
                    $maintainer_update = '';
                    if ($new_status == 2 && empty($task['maintainer_id'])) {
                        $maintainer_update = 'maintainer_id = ' . (isset($_SESSION['user_id']) ? $_SESSION['user_id'] : 'NULL') . ',';
                    }

                    $stmt = $pdo->prepare("
                        UPDATE room_maintenance 
                        SET status = ?, 
                            $maintainer_update
                            $complete_time
                            issue_desc = CONCAT(issue_desc, IF(? > '', CONCAT('\n--- 完成备注 ---\n', ?), ''))
                        WHERE id = ?
                    ");
                    $result = $stmt->execute([
                        $new_status,
                        $completion_notes,
                        $completion_notes,
                        $task_id
                    ]);

                    if ($result) {
                        $status_texts = [1 => '待处理', 2 => '处理中', 3 => '已完成'];
                        record_log("更新房间 {$task['room_number']} 的维修任务状态为 {$status_texts[$new_status]}，问题类型：{$task['issue_type']}");

                        // 如果任务完成，尝试更新房间状态为可用
                        if ($new_status == 3) {
                            try {
                                $stmt = $pdo->prepare("UPDATE room_info SET status = 1 WHERE id = ? AND status = 5");
                                $stmt->execute([$task['room_id']]);
                                record_log("房间 {$task['room_number']} 维修完成，状态已更新为可用");
                            } catch (PDOException $e) {
                                // 记录错误但不中断流程
                                error_log("更新房间状态失败：" . $e->getMessage());
                            }
                        }

                        $success = '维修任务状态更新成功！';
                    } else {
                        $error = '维修任务状态更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除维修任务
    elseif ($_POST['action'] == 'delete') {
        $task_id = isset($_POST['task_id']) ? intval($_POST['task_id']) : 0;

        if ($task_id <= 0) {
            $error = '无效的任务ID！';
        } else {
            try {
                // 获取任务信息用于日志记录
                $stmt = $pdo->prepare("
                    SELECT m.issue_type, r.room_number 
                    FROM room_maintenance m
                    JOIN room_info r ON m.room_id = r.id
                    WHERE m.id = ?
                ");
                $stmt->execute([$task_id]);
                $task = $stmt->fetch();

                if (!$task) {
                    $error = '维修任务不存在！';
                } else {
                    $stmt = $pdo->prepare("DELETE FROM room_maintenance WHERE id = ?");
                    $result = $stmt->execute([$task_id]);

                    if ($result) {
                        record_log("删除房间 {$task['room_number']} 的维修任务：{$task['issue_type']}");
                        $success = '维修任务删除成功！';
                    } else {
                        $error = '维修任务删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 判断是否显示添加表单
$show_add_form = isset($_GET['show_form']) && $_GET['show_form'] == 'add';

// 如果是更新任务状态请求，获取任务详情
$update_task = null;
$update_task_id = isset($_GET['update']) ? intval($_GET['update']) : 0;
if ($update_task_id > 0) {
    try {
        $stmt = $pdo->prepare("
            SELECT m.*, r.room_number, r.floor 
            FROM room_maintenance m
            JOIN room_info r ON m.room_id = r.id
            WHERE m.id = ?
        ");
        $stmt->execute([$update_task_id]);
        $update_task = $stmt->fetch();
    } catch (PDOException $e) {
        $error = '获取任务详情失败：' . $e->getMessage();
    }
}

// 获取所有房间
try {
    $stmt = $pdo->query("
        SELECT r.id, r.room_number, r.floor, r.status, t.type_name 
        FROM room_info r
        JOIN room_types t ON r.room_type_id = t.id  
        ORDER BY r.floor, r.room_number
    ");
    $rooms = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取房间列表失败：' . $e->getMessage();
    $rooms = [];
}

// 获取维修人员列表
try {
    $stmt = $pdo->query("SELECT id, username FROM sys_users WHERE status = 1 ORDER BY username");
    $maintenance_staff = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取维修人员列表失败：' . $e->getMessage();
    $maintenance_staff = [];
}

// 获取维修任务列表
$status_filter = isset($_GET['status']) ? intval($_GET['status']) : 0;
$floor_filter = isset($_GET['floor']) ? trim($_GET['floor']) : '';

try {
    $sql = "
        SELECT m.*, r.room_number, r.floor, u1.username as reporter_name, u2.username as maintainer_name
        FROM room_maintenance m
        JOIN room_info r ON m.room_id = r.id
        LEFT JOIN sys_users u1 ON m.reporter_id = u1.id
        LEFT JOIN sys_users u2 ON m.maintainer_id = u2.id
        WHERE 1=1
    ";
    $params = [];

    if ($status_filter > 0) {
        $sql .= " AND m.status = ?";
        $params[] = $status_filter;
    }

    if (!empty($floor_filter)) {
        $sql .= " AND r.floor = ?";
        $params[] = $floor_filter;
    }

    $sql .= " ORDER BY 
              CASE m.status 
                WHEN 1 THEN 1 
                WHEN 2 THEN 2 
                WHEN 3 THEN 3 
                ELSE 4 
              END, 
              m.report_time DESC";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $tasks = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取维修任务列表失败：' . $e->getMessage();
    $tasks = [];
}

// 获取楼层列表
try {
    $stmt = $pdo->query("SELECT DISTINCT floor FROM room_info ORDER BY floor");
    $floors = $stmt->fetchAll(PDO::FETCH_COLUMN);
} catch (PDOException $e) {
    $floors = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>客房维修管理</title>
    <link rel="stylesheet" href="../style.css">
    <style>
        .task-status-1 {
            background-color: #fff3cd;
        }

        .task-status-2 {
            background-color: #cfe2ff;
        }

        .task-status-3 {
            background-color: #d1e7dd;
        }

        .priority-3 {
            border-left: 4px solid #dc3545;
        }

        .priority-2 {
            border-left: 4px solid #fd7e14;
        }

        .priority-1 {
            border-left: 4px solid #0d6efd;
        }
    </style>
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>客房维修管理</h2>
            <div class="breadcrumb">
                <a href="index.php">客房管理</a> &gt; 维修管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <?php if (!$show_add_form && !$update_task): ?>
                    <a href="maintenance.php?show_form=add" class="btn btn-primary">添加维修任务</a>
                <?php endif; ?>
            </div>

            <?php if ($show_add_form): ?>
                <!-- 添加维修任务表单 -->
                <h3>添加维修任务</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add">

                        <div class="form-group">
                            <label for="room_id">选择房间：</label>
                            <select id="room_id" name="room_id" required>
                                <option value="">-- 请选择房间 --</option>
                                <?php foreach ($rooms as $room): ?>
                                    <option value="<?php echo $room['id']; ?>">
                                        <?php echo $room['room_number']; ?> (<?php echo $room['floor']; ?>楼 - <?php echo $room['type_name']; ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="issue_type">问题类型：</label>
                            <select id="issue_type" name="issue_type" required>
                                <option value="">-- 请选择类型 --</option>
                                <option value="水电">水电问题</option>
                                <option value="家具">家具损坏</option>
                                <option value="电器">电器故障</option>
                                <option value="结构">结构问题</option>
                                <option value="安全">安全隐患</option>
                                <option value="其他">其他问题</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="issue_desc">问题描述：</label>
                            <textarea id="issue_desc" name="issue_desc" rows="3" required></textarea>
                        </div>

                        <div class="form-group">
                            <label for="priority">优先级：</label>
                            <select id="priority" name="priority">
                                <option value="1">普通</option>
                                <option value="2">紧急</option>
                                <option value="3">高度紧急</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="maintainer_id">分配给：</label>
                            <select id="maintainer_id" name="maintainer_id">
                                <option value="">-- 暂不分配 --</option>
                                <?php foreach ($maintenance_staff as $staff): ?>
                                    <option value="<?php echo $staff['id']; ?>">
                                        <?php echo $staff['username']; ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="maintenance.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($update_task): ?>
                <!-- 更新维修任务状态表单 -->
                <h3>更新维修任务状态</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="update_status">
                        <input type="hidden" name="task_id" value="<?php echo $update_task['id']; ?>">

                        <div class="form-group">
                            <label>房间号：</label>
                            <input type="text" value="<?php echo $update_task['room_number']; ?>" readonly class="form-control-plaintext">
                        </div>

                        <div class="form-group">
                            <label>问题类型：</label>
                            <input type="text" value="<?php echo $update_task['issue_type']; ?>" readonly class="form-control-plaintext">
                        </div>

                        <div class="form-group">
                            <label>问题描述：</label>
                            <textarea readonly class="form-control-plaintext" rows="3"><?php echo $update_task['issue_desc']; ?></textarea>
                        </div>

                        <div class="form-group">
                            <label>报修时间：</label>
                            <input type="text" value="<?php echo $update_task['report_time']; ?>" readonly class="form-control-plaintext">
                        </div>

                        <div class="form-group">
                            <label for="status">更新状态为：</label>
                            <select id="status" name="status" required>
                                <option value="1" <?php echo $update_task['status'] == 1 ? 'selected' : ''; ?>>待处理</option>
                                <option value="2" <?php echo $update_task['status'] == 2 ? 'selected' : ''; ?>>处理中</option>
                                <option value="3" <?php echo $update_task['status'] == 3 ? 'selected' : ''; ?>>已完成</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="completion_notes">完成备注：</label>
                            <textarea id="completion_notes" name="completion_notes" rows="3"><?php echo isset($completion_notes) ? $completion_notes : ''; ?></textarea>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="maintenance.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="0">全部</option>
                                <option value="1" <?php echo $status_filter == 1 ? 'selected' : ''; ?>>待处理</option>
                                <option value="2" <?php echo $status_filter == 2 ? 'selected' : ''; ?>>处理中</option>
                                <option value="3" <?php echo $status_filter == 3 ? 'selected' : ''; ?>>已完成</option>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="floor">楼层：</label>
                            <select id="floor" name="floor">
                                <option value="">全部</option>
                                <?php foreach ($floors as $floor): ?>
                                    <option value="<?php echo $floor; ?>" <?php echo $floor_filter == $floor ? 'selected' : ''; ?>>
                                        <?php echo $floor; ?>楼
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="filter-item">
                            <button type="submit" class="btn btn-primary">筛选</button>
                            <a href="maintenance.php" class="btn btn-secondary">重置</a>
                        </div>
                    </div>
                </form>
            </div>

            <h3>维修任务列表</h3>
            <div class="data-list">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>房间号</th>
                            <th>问题类型</th>
                            <th>问题描述</th>
                            <th>状态</th>
                            <th>报修人</th>
                            <th>维修人</th>
                            <th>报修时间</th>
                            <th>完成时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($tasks as $task): ?>
                            <tr class="task-status-<?php echo $task['status']; ?>">
                                <td><?php echo $task['id']; ?></td>
                                <td><?php echo $task['room_number']; ?> (<?php echo $task['floor']; ?>楼)</td>
                                <td><?php echo $task['issue_type']; ?></td>
                                <td>
                                    <?php
                                    // 显示问题描述的前50个字符
                                    echo mb_strlen($task['issue_desc']) > 50
                                        ? mb_substr($task['issue_desc'], 0, 50) . '...'
                                        : $task['issue_desc'];
                                    ?>
                                </td>
                                <td>
                                    <?php
                                    switch ($task['status']) {
                                        case 1:
                                            echo '<span style="color: #ff9800;">待处理</span>';
                                            break;
                                        case 2:
                                            echo '<span style="color: #0d6efd;">处理中</span>';
                                            break;
                                        case 3:
                                            echo '<span style="color: #198754;">已完成</span>';
                                            break;
                                        default:
                                            echo '<span>未知</span>';
                                    }
                                    ?>
                                </td>
                                <td><?php echo $task['reporter_name'] ?: '系统'; ?></td>
                                <td><?php echo $task['maintainer_name'] ?: '未分配'; ?></td>
                                <td><?php echo $task['report_time']; ?></td>
                                <td><?php echo $task['complete_time'] ?: '-'; ?></td>
                                <td>
                                    <a href="maintenance.php?update=<?php echo $task['id']; ?>" class="btn btn-sm btn-edit">更新状态</a>

                                    <?php if ($task['status'] != 3): ?>
                                        <form method="post" action="" style="display:inline;" onsubmit="return confirm('确定要删除此维修任务吗？此操作不可恢复！');">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="task_id" value="<?php echo $task['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger">删除</button>
                                        </form>
                                    <?php endif; ?>
                                </td>
                            </tr>
                        <?php endforeach; ?>

                        <?php if (empty($tasks)): ?>
                            <tr>
                                <td colspan="10" style="text-align: center;">没有找到维修任务</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <script>
        // 根据问题类型设置默认优先级
        document.addEventListener('DOMContentLoaded', function() {
            const issueTypeSelect = document.getElementById('issue_type');
            const prioritySelect = document.getElementById('priority');

            if (issueTypeSelect && prioritySelect) {
                issueTypeSelect.addEventListener('change', function() {
                    const selectedType = this.value;
                    if (['水电', '结构', '安全'].includes(selectedType)) {
                        prioritySelect.value = '3'; // 高度紧急
                    } else if (selectedType === '电器') {
                        prioritySelect.value = '2'; // 紧急
                    } else {
                        prioritySelect.value = '1'; // 普通
                    }
                });
            }
        });
    </script>
</body>

</html>