<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('stat_view');

// 记录访问日志
record_log('访问统计分析首页');

// 获取当前日期
$today = date('Y-m-d');
$current_month = date('m');
$current_year = date('Y');
$yesterday = date('Y-m-d', strtotime('-1 day'));

// 获取今日统计数据
try {
    $stmt = $pdo->prepare("SELECT * FROM report_daily_statistics WHERE stat_date = ?");
    $stmt->execute([$today]);
    $today_stats = $stmt->fetch();

    // 如果今日数据不存在，获取最近的统计数据
    if (!$today_stats) {
        $stmt = $pdo->query("SELECT * FROM report_daily_statistics ORDER BY stat_date DESC LIMIT 1");
        $today_stats = $stmt->fetch();
    }
} catch (PDOException $e) {
    $error = '获取今日统计数据失败：' . $e->getMessage();
    $today_stats = null;
}

// 获取本月统计数据
try {
    $stmt = $pdo->prepare("SELECT * FROM report_monthly_statistics WHERE year = ? AND month = ?");
    $stmt->execute([$current_year, $current_month]);
    $month_stats = $stmt->fetch();

    // 如果本月数据不存在，获取最近月份的统计数据
    if (!$month_stats) {
        $stmt = $pdo->query("SELECT * FROM report_monthly_statistics ORDER BY year DESC, month DESC LIMIT 1");
        $month_stats = $stmt->fetch();
    }
} catch (PDOException $e) {
    $error = '获取月度统计数据失败：' . $e->getMessage();
    $month_stats = null;
}

// 获取入住率趋势（最近7天）
try {
    $stmt = $pdo->prepare("
        SELECT stat_date, occupancy_rate 
        FROM report_daily_statistics 
        WHERE stat_date <= ? 
        ORDER BY stat_date DESC 
        LIMIT 7
    ");
    $stmt->execute([$today]);
    $occupancy_trend = $stmt->fetchAll();
    $occupancy_trend = array_reverse($occupancy_trend); // 按日期正序排列
} catch (PDOException $e) {
    $error = '获取入住率趋势失败：' . $e->getMessage();
    $occupancy_trend = [];
}

// 获取最近收入趋势（最近7天）
try {
    $stmt = $pdo->prepare("
        SELECT stat_date, total_revenue 
        FROM report_daily_statistics 
        WHERE stat_date <= ? 
        ORDER BY stat_date DESC 
        LIMIT 7
    ");
    $stmt->execute([$today]);
    $revenue_trend = $stmt->fetchAll();
    $revenue_trend = array_reverse($revenue_trend); // 按日期正序排列
} catch (PDOException $e) {
    $error = '获取收入趋势失败：' . $e->getMessage();
    $revenue_trend = [];
}

// 获取OTA订单比例
try {
    $stmt = $pdo->prepare("
        SELECT 
            SUM(ota_bookings) as ota_bookings, 
            SUM(new_bookings) as total_bookings
        FROM report_daily_statistics 
        WHERE stat_date BETWEEN DATE_SUB(?, INTERVAL 30 DAY) AND ?
    ");
    $stmt->execute([$today, $today]);
    $booking_stats = $stmt->fetch();

    if ($booking_stats && $booking_stats['total_bookings'] > 0) {
        $ota_percentage = round(($booking_stats['ota_bookings'] / $booking_stats['total_bookings']) * 100, 2);
    } else {
        $ota_percentage = 0;
    }
} catch (PDOException $e) {
    $error = '获取OTA订单比例失败：' . $e->getMessage();
    $ota_percentage = 0;
}

// 获取房型使用率
try {
    $stmt = $pdo->query("
        SELECT r.type_name, COUNT(c.room_id) as occupied_count, 
               (SELECT COUNT(*) FROM room_info WHERE room_type_id = r.id) as total_count
        FROM room_types r
        LEFT JOIN room_info ri ON r.id = ri.room_type_id
        LEFT JOIN checkin_orders c ON ri.id = c.room_id AND c.status = 1
        GROUP BY r.id, r.type_name
    ");
    $room_usage = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取房型使用率失败：' . $e->getMessage();
    $room_usage = [];
}

// 获取最近保存的报表
try {
    $stmt = $pdo->query("
        SELECT * FROM report_saved_reports
        WHERE is_public = 1
        ORDER BY last_run_time DESC
        LIMIT 5
    ");
    $saved_reports = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取保存的报表失败：' . $e->getMessage();
    $saved_reports = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>统计分析</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>统计分析中心</h2>
            <div class="breadcrumb">
                <a href="../index.php">首页</a> &gt; 统计分析
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <!-- 关键指标概览 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>今日入住率</h3>
                    <div class="number"><?php echo $today_stats ? $today_stats['occupancy_rate'] . '%' : 'N/A'; ?></div>
                    <div class="desc">可用房间数：<?php echo $today_stats ? $today_stats['available_rooms'] : 'N/A'; ?> | 已住：<?php echo $today_stats ? $today_stats['occupied_rooms'] : 'N/A'; ?></div>
                </div>
                <div class="dashboard-card">
                    <h3>今日总收入</h3>
                    <div class="number">￥<?php echo $today_stats ? number_format($today_stats['total_revenue'], 2) : 'N/A'; ?></div>
                    <div class="desc">房费：￥<?php echo $today_stats ? number_format($today_stats['room_revenue'], 2) : 'N/A'; ?> | 其他：￥<?php echo $today_stats ? number_format($today_stats['other_revenue'], 2) : 'N/A'; ?></div>
                </div>
                <div class="dashboard-card">
                    <h3>本月平均房价</h3>
                    <div class="number">￥<?php echo $month_stats ? number_format($month_stats['avg_room_rate'], 2) : 'N/A'; ?></div>
                    <div class="desc">RevPAR：￥<?php echo $month_stats ? number_format($month_stats['revpar'], 2) : 'N/A'; ?></div>
                </div>
                <div class="dashboard-card">
                    <h3>OTA贡献率</h3>
                    <div class="number"><?php echo $month_stats ? $month_stats['ota_contribution_rate'] . '%' : ($ota_percentage . '%'); ?></div>
                    <div class="desc">最近30天数据</div>
                </div>
            </div>

            <!-- 功能链接 -->
            <div class="function-links">
                <a href="occupancy.php" class="function-link">
                    <h3>入住率分析</h3>                    
                </a>
                <a href="room_usage.php" class="function-link">
                    <h3>房间利用率</h3>          
                </a>
                <a href="order_analysis.php" class="function-link">
                    <h3>订单数据分析</h3>                
                </a>
                <a href="../finance/report.php" class="function-link">
                    <h3>财务报表</h3>                    
                </a>
                <a href="custom_reports.php" class="function-link">
                    <h3>自定义报表</h3>
                </a>
            </div>

            <!-- 入住率趋势图 -->
            <h3>入住率趋势（近7天）</h3>
            <div class="chart-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <?php foreach ($occupancy_trend as $day): ?>
                                <th><?php echo date('m-d', strtotime($day['stat_date'])); ?></th>
                            <?php endforeach; ?>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <?php foreach ($occupancy_trend as $day): ?>
                                <td><?php echo $day['occupancy_rate']; ?>%</td>
                            <?php endforeach; ?>
                        </tr>
                    </tbody>
                </table>
            </div>

            <!-- 房型使用情况 -->
            <h3>房型使用情况</h3>
            <div class="data-list">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>房型</th>
                            <th>总房间数</th>
                            <th>已入住</th>
                            <th>使用率</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($room_usage as $room): ?>
                            <tr>
                                <td><?php echo $room['type_name']; ?></td>
                                <td><?php echo $room['total_count']; ?></td>
                                <td><?php echo $room['occupied_count']; ?></td>
                                <td>
                                    <?php
                                    if ($room['total_count'] > 0) {
                                        $usage_rate = round(($room['occupied_count'] / $room['total_count']) * 100, 2);
                                        echo $usage_rate . '%';
                                    } else {
                                        echo 'N/A';
                                    }
                                    ?>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>

            <!-- 收入趋势 -->
            <h3>收入趋势（近7天）</h3>
            <div class="chart-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <?php foreach ($revenue_trend as $day): ?>
                                <th><?php echo date('m-d', strtotime($day['stat_date'])); ?></th>
                            <?php endforeach; ?>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <?php foreach ($revenue_trend as $day): ?>
                                <td>￥<?php echo number_format($day['total_revenue'], 2); ?></td>
                            <?php endforeach; ?>
                        </tr>
                    </tbody>
                </table>
            </div>

            <!-- 保存的报表 -->
            <?php if (count($saved_reports) > 0): ?>
                <h3>最近保存的报表</h3>
                <div class="data-list">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>报表名称</th>
                                <th>报表类型</th>
                                <th>图表类型</th>
                                <th>最后运行时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($saved_reports as $report): ?>
                                <tr>
                                    <td><?php echo $report['report_name']; ?></td>
                                    <td>
                                        <?php
                                        switch ($report['report_type']) {
                                            case 1:
                                                echo '入住率分析';
                                                break;
                                            case 2:
                                                echo '营收分析';
                                                break;
                                            case 3:
                                                echo '渠道分析';
                                                break;
                                            case 4:
                                                echo '客户分析';
                                                break;
                                            default:
                                                echo '未知';
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo $report['chart_type']; ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($report['last_run_time'])); ?></td>
                                    <td>
                                        <a href="view_report.php?id=<?php echo $report['id']; ?>" class="btn btn-sm btn-primary">查看</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>