<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('stat_view');

// 记录访问日志
record_log('访问订单数据分析页面');

// 获取当前日期和时间范围
$today = date('Y-m-d');
$current_month = date('m');
$current_year = date('Y');
$yesterday = date('Y-m-d', strtotime('-1 day'));

// 获取筛选条件
$date_range = isset($_GET['date_range']) ? $_GET['date_range'] : 'month';
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-01'); // 默认本月初
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d'); // 默认今天
$channel_id = isset($_GET['channel_id']) ? intval($_GET['channel_id']) : 0;

// 根据日期范围设置默认值
if ($date_range == 'week') {
    $start_date = date('Y-m-d', strtotime('-6 days'));
    $end_date = $today;
} elseif ($date_range == 'month') {
    $start_date = date('Y-m-01');
    $end_date = date('Y-m-d', strtotime('last day of this month'));
} elseif ($date_range == 'year') {
    $start_date = date('Y-01-01');
    $end_date = date('Y-12-31');
} elseif ($date_range == 'last_month') {
    $start_date = date('Y-m-01', strtotime('first day of last month'));
    $end_date = date('Y-m-d', strtotime('last day of last month'));
}

// 获取所有预订渠道
try {
    $stmt = $pdo->query("SELECT id, channel_name FROM booking_channels WHERE status = 1 ORDER BY id");
    $channels = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取预订渠道列表失败：' . $e->getMessage();
    $channels = [];
}

// 计算订单统计数据
$order_stats = [];
$channel_stats = [];
$daily_stats = [];
$total_orders = 0;
$total_rooms = 0;
$total_revenue = 0;
$cancelled_orders = 0;
$avg_room_rate = 0;
$avg_stay_days = 0;

try {
    // 构建基础SQL查询条件
    $where_conditions = "WHERE (DATE(bo.create_time) BETWEEN ? AND ?)";
    $params = [$start_date, $end_date];

    if ($channel_id > 0) {
        $where_conditions .= " AND bo.channel_id = ?";
        $params[] = $channel_id;
    }

    // 获取总订单数、总房间数、总收入、取消订单数
    $sql = "
        SELECT 
            COUNT(DISTINCT bo.id) as total_orders,
            SUM(bo.room_count) as total_rooms,
            SUM(bo.total_amount) as total_revenue,
            SUM(CASE WHEN bo.status = 0 THEN 1 ELSE 0 END) as cancelled_orders,
            AVG(bo.room_rate) as avg_room_rate,
            AVG(DATEDIFF(bo.departure_date, bo.arrival_date)) as avg_stay_days
        FROM booking_orders bo
        $where_conditions
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $order_stats = $stmt->fetch();

    $total_orders = $order_stats['total_orders'] ?: 0;
    $total_rooms = $order_stats['total_rooms'] ?: 0;
    $total_revenue = $order_stats['total_revenue'] ?: 0;
    $cancelled_orders = $order_stats['cancelled_orders'] ?: 0;
    $avg_room_rate = $order_stats['avg_room_rate'] ?: 0;
    $avg_stay_days = $order_stats['avg_stay_days'] ?: 0;

    // 计算取消率
    $cancellation_rate = $total_orders > 0 ? round(($cancelled_orders / $total_orders) * 100, 2) : 0;

    // 获取按渠道分组的订单统计
    $sql = "
        SELECT 
            bc.id as channel_id,
            bc.channel_name,
            COUNT(bo.id) as order_count,
            SUM(bo.room_count) as room_count,
            SUM(bo.total_amount) as revenue,
            SUM(CASE WHEN bo.status = 0 THEN 1 ELSE 0 END) as cancelled_count,
            AVG(bo.room_rate) as avg_rate
        FROM booking_channels bc
        LEFT JOIN booking_orders bo ON bc.id = bo.channel_id AND (DATE(bo.create_time) BETWEEN ? AND ?)
        " . ($channel_id > 0 ? "WHERE bc.id = ?" : "WHERE bc.status = 1") . "
        GROUP BY bc.id, bc.channel_name
        ORDER BY order_count DESC
    ";

    $params = [$start_date, $end_date];
    if ($channel_id > 0) {
        $params[] = $channel_id;
    }

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $channel_stats = $stmt->fetchAll();

    // 计算各渠道的取消率和占比
    foreach ($channel_stats as &$stat) {
        $stat['cancellation_rate'] = $stat['order_count'] > 0 ?
            round(($stat['cancelled_count'] / $stat['order_count']) * 100, 2) : 0;
        $stat['order_percentage'] = $total_orders > 0 ?
            round(($stat['order_count'] / $total_orders) * 100, 2) : 0;
        $stat['revenue_percentage'] = $total_revenue > 0 ?
            round(($stat['revenue'] / $total_revenue) * 100, 2) : 0;
    }

    // 获取每日订单统计
    $current_date = $start_date;
    while (strtotime($current_date) <= strtotime($end_date)) {
        $daily_stats[$current_date] = [
            'date' => $current_date,
            'order_count' => 0,
            'room_count' => 0,
            'revenue' => 0,
            'cancelled_count' => 0,
            'channels' => []
        ];

        // 初始化每个渠道的数据
        foreach ($channels as $channel) {
            $daily_stats[$current_date]['channels'][$channel['id']] = [
                'id' => $channel['id'],
                'name' => $channel['channel_name'],
                'order_count' => 0,
                'room_count' => 0,
                'revenue' => 0
            ];
        }

        $current_date = date('Y-m-d', strtotime($current_date . ' + 1 day'));
    }

    // 获取每日各渠道的订单情况
    $sql = "
        SELECT 
            DATE(bo.create_time) as order_date,
            bo.channel_id,
            bc.channel_name,
            COUNT(bo.id) as daily_orders,
            SUM(bo.room_count) as daily_rooms,
            SUM(bo.total_amount) as daily_revenue,
            SUM(CASE WHEN bo.status = 0 THEN 1 ELSE 0 END) as daily_cancelled
        FROM booking_orders bo
        JOIN booking_channels bc ON bo.channel_id = bc.id
        WHERE DATE(bo.create_time) BETWEEN ? AND ?
        " . ($channel_id > 0 ? "AND bo.channel_id = ?" : "") . "
        GROUP BY order_date, bo.channel_id, bc.channel_name
        ORDER BY order_date, bo.channel_id
    ";

    $params = [$start_date, $end_date];
    if ($channel_id > 0) {
        $params[] = $channel_id;
    }

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $daily_orders = $stmt->fetchAll();

    // 填充每日统计数据
    foreach ($daily_orders as $order) {
        if (isset($daily_stats[$order['order_date']])) {
            $daily_stats[$order['order_date']]['order_count'] += $order['daily_orders'];
            $daily_stats[$order['order_date']]['room_count'] += $order['daily_rooms'];
            $daily_stats[$order['order_date']]['revenue'] += $order['daily_revenue'];
            $daily_stats[$order['order_date']]['cancelled_count'] += $order['daily_cancelled'];

            if (isset($daily_stats[$order['order_date']]['channels'][$order['channel_id']])) {
                $daily_stats[$order['order_date']]['channels'][$order['channel_id']]['order_count'] = $order['daily_orders'];
                $daily_stats[$order['order_date']]['channels'][$order['channel_id']]['room_count'] = $order['daily_rooms'];
                $daily_stats[$order['order_date']]['channels'][$order['channel_id']]['revenue'] = $order['daily_revenue'];
            }
        }
    }

    // 获取按房型分组的订单统计
    $sql = "
        SELECT 
            rt.id as room_type_id,
            rt.type_name,
            COUNT(bo.id) as order_count,
            SUM(bo.room_count) as room_count,
            SUM(bo.total_amount) as revenue,
            AVG(bo.room_rate) as avg_rate
        FROM room_types rt
        LEFT JOIN booking_orders bo ON rt.id = bo.room_type_id AND DATE(bo.create_time) BETWEEN ? AND ?
        " . ($channel_id > 0 ? "AND bo.channel_id = ?" : "") . "
        WHERE rt.status = 1
        GROUP BY rt.id, rt.type_name
        ORDER BY order_count DESC
    ";

    $params = [$start_date, $end_date];
    if ($channel_id > 0) {
        $params[] = $channel_id;
    }

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $room_type_stats = $stmt->fetchAll();

    // 计算各房型的占比
    foreach ($room_type_stats as &$stat) {
        $stat['order_percentage'] = $total_orders > 0 ?
            round(($stat['order_count'] / $total_orders) * 100, 2) : 0;
        $stat['revenue_percentage'] = $total_revenue > 0 ?
            round(($stat['revenue'] / $total_revenue) * 100, 2) : 0;
    }

    // 获取订单状态统计
    $sql = "
        SELECT 
            bo.status,
            CASE 
                WHEN bo.status = 0 THEN '已取消'
                WHEN bo.status = 1 THEN '已确认'
                WHEN bo.status = 2 THEN '已入住'
                WHEN bo.status = 3 THEN '已完成'
                ELSE '未知状态'
            END as status_name,
            COUNT(bo.id) as order_count,
            SUM(bo.room_count) as room_count,
            SUM(bo.total_amount) as revenue
        FROM booking_orders bo
        WHERE DATE(bo.create_time) BETWEEN ? AND ?
        " . ($channel_id > 0 ? "AND bo.channel_id = ?" : "") . "
        GROUP BY bo.status
        ORDER BY bo.status
    ";

    $params = [$start_date, $end_date];
    if ($channel_id > 0) {
        $params[] = $channel_id;
    }

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $status_stats = $stmt->fetchAll();

    // 计算各状态的占比
    foreach ($status_stats as &$stat) {
        $stat['order_percentage'] = $total_orders > 0 ?
            round(($stat['order_count'] / $total_orders) * 100, 2) : 0;
    }
} catch (PDOException $e) {
    $error = '获取订单统计数据失败：' . $e->getMessage();
    $channel_stats = [];
    $daily_stats = [];
    $room_type_stats = [];
    $status_stats = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>订单数据分析</title>
    <link rel="stylesheet" href="../style.css">
    <style>
        .summary-box {
            display: flex;
            flex-wrap: wrap;
            gap: 20px;
            margin-bottom: 20px;
        }

        .summary-item {
            flex: 1;
            min-width: 200px;
            background: #f8f9fa;
            padding: 15px;
            border-radius: 4px;
            border: 1px solid #ddd;
            text-align: center;
        }

        .summary-label {
            display: block;
            font-weight: bold;
            margin-bottom: 5px;
            color: #666;
        }

        .summary-value {
            display: block;
            font-size: 24px;
            font-weight: bold;
            color: #4CAF50;
        }

        .chart-container {
            width: 100%;
            margin-bottom: 20px;
            overflow-x: auto;
        }

        .status-high {
            color: #28a745;
            font-weight: bold;
        }

        .status-medium {
            color: #fd7e14;
        }

        .status-low {
            color: #dc3545;
        }

        .progress-bar {
            height: 20px;
            background-color: #e9ecef;
            border-radius: 3px;
            margin-top: 5px;
            overflow: hidden;
        }

        .progress-bar-fill {
            height: 100%;
            background-color: #4CAF50;
            text-align: center;
            line-height: 20px;
            color: white;
            transition: width 0.5s;
        }

        .cancel-rate-high {
            background-color: #dc3545;
        }

        .cancel-rate-medium {
            background-color: #fd7e14;
        }

        .cancel-rate-low {
            background-color: #28a745;
        }
    </style>
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>订单数据分析</h2>
            <div class="breadcrumb">
                <a href="index.php">统计分析</a> &gt; 订单数据分析
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="date_range">时间范围：</label>
                            <select id="date_range" name="date_range" onchange="updateDateRange()">
                                <option value="week" <?php echo $date_range == 'week' ? 'selected' : ''; ?>>近7天</option>
                                <option value="month" <?php echo $date_range == 'month' ? 'selected' : ''; ?>>本月</option>
                                <option value="last_month" <?php echo $date_range == 'last_month' ? 'selected' : ''; ?>>上月</option>
                                <option value="year" <?php echo $date_range == 'year' ? 'selected' : ''; ?>>本年</option>
                                <option value="custom" <?php echo $date_range == 'custom' ? 'selected' : ''; ?>>自定义</option>
                            </select>
                        </div>
                        <div class="filter-item" id="custom_date" style="<?php echo $date_range == 'custom' ? '' : 'display:none;'; ?>">
                            <label for="start_date">开始日期：</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo $start_date; ?>">
                        </div>
                        <div class="filter-item" id="custom_date_end" style="<?php echo $date_range == 'custom' ? '' : 'display:none;'; ?>">
                            <label for="end_date">结束日期：</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo $end_date; ?>">
                        </div>
                    </div>
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="channel_id">预订渠道：</label>
                            <select id="channel_id" name="channel_id">
                                <option value="0">全部渠道</option>
                                <?php foreach ($channels as $ch): ?>
                                    <option value="<?php echo $ch['id']; ?>" <?php echo $channel_id == $ch['id'] ? 'selected' : ''; ?>><?php echo $ch['channel_name']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="filter-buttons">
                            <button type="submit" class="btn btn-primary">分析</button>
                            <a href="order.php" class="btn btn-secondary">重置</a>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 订单概览 -->
            <div class="summary-box">
                <div class="summary-item">
                    <span class="summary-label">总订单数</span>
                    <span class="summary-value"><?php echo $total_orders; ?></span>
                    <span>日期范围：<?php echo $start_date; ?> 至 <?php echo $end_date; ?></span>
                </div>
                <div class="summary-item">
                    <span class="summary-label">总收入</span>
                    <span class="summary-value">￥<?php echo number_format($total_revenue, 2); ?></span>
                </div>
                <div class="summary-item">
                    <span class="summary-label">订单取消率</span>
                    <span class="summary-value"><?php echo $cancellation_rate; ?>%</span>
                    <span>已取消订单：<?php echo $cancelled_orders; ?></span>
                </div>
                <div class="summary-item">
                    <span class="summary-label">平均房价</span>
                    <span class="summary-value">￥<?php echo number_format($avg_room_rate, 2); ?></span>
                    <span>平均入住天数：<?php echo number_format($avg_stay_days, 1); ?> 天</span>
                </div>
            </div>

            <!-- 按渠道分析 -->
            <h3>订单来源渠道分析</h3>
            <div class="data-list">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>渠道</th>
                            <th>订单数</th>
                            <th>订单占比</th>
                            <th>房间数</th>
                            <th>收入(元)</th>
                            <th>收入占比</th>
                            <th>平均房价(元)</th>
                            <th>取消率</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($channel_stats as $stat): ?>
                            <tr>
                                <td><?php echo $stat['channel_name']; ?></td>
                                <td><?php echo $stat['order_count']; ?></td>
                                <td>
                                    <?php echo $stat['order_percentage']; ?>%
                                    <div class="progress-bar">
                                        <div class="progress-bar-fill" style="width: <?php echo $stat['order_percentage']; ?>%;">
                                            <?php echo $stat['order_percentage']; ?>%
                                        </div>
                                    </div>
                                </td>
                                <td><?php echo $stat['room_count']; ?></td>
                                <td><?php echo number_format($stat['revenue'], 2); ?></td>
                                <td>
                                    <?php echo $stat['revenue_percentage']; ?>%
                                    <div class="progress-bar">
                                        <div class="progress-bar-fill" style="width: <?php echo $stat['revenue_percentage']; ?>%;">
                                            <?php echo $stat['revenue_percentage']; ?>%
                                        </div>
                                    </div>
                                </td>
                                <td><?php echo number_format($stat['avg_rate'], 2); ?></td>
                                <td>
                                    <?php echo $stat['cancellation_rate']; ?>%
                                    <div class="progress-bar">
                                        <div class="progress-bar-fill <?php
                                                                        if ($stat['cancellation_rate'] > 20) echo 'cancel-rate-high';
                                                                        elseif ($stat['cancellation_rate'] > 10) echo 'cancel-rate-medium';
                                                                        else echo 'cancel-rate-low';
                                                                        ?>" style="width: <?php echo $stat['cancellation_rate']; ?>%;">
                                            <?php echo $stat['cancellation_rate']; ?>%
                                        </div>
                                    </div>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (count($channel_stats) == 0): ?>
                            <tr>
                                <td colspan="8" class="text-center">暂无渠道数据</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 每日订单统计 -->
            <h3>每日订单统计</h3>
            <div class="data-list">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>日期</th>
                            <th>订单数</th>
                            <th>房间数</th>
                            <th>收入(元)</th>
                            <th>取消订单数</th>
                            <?php if ($channel_id == 0): ?>
                                <th>渠道详情</th>
                            <?php endif; ?>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($daily_stats as $day): ?>
                            <tr>
                                <td><?php echo $day['date']; ?></td>
                                <td><?php echo $day['order_count']; ?></td>
                                <td><?php echo $day['room_count']; ?></td>
                                <td><?php echo number_format($day['revenue'], 2); ?></td>
                                <td><?php echo $day['cancelled_count']; ?></td>
                                <?php if ($channel_id == 0 && !empty($day['channels'])): ?>
                                    <td>
                                        <button type="button" class="btn btn-sm btn-details" onclick="toggleChannelDetails('<?php echo $day['date']; ?>')">查看详情</button>
                                    </td>
                                <?php endif; ?>
                            </tr>
                            <?php if ($channel_id == 0 && !empty($day['channels'])): ?>
                                <tr id="channel-details-<?php echo $day['date']; ?>" style="display: none;">
                                    <td colspan="6">
                                        <table class="data-table" style="margin: 0;">
                                            <thead>
                                                <tr>
                                                    <th>渠道</th>
                                                    <th>订单数</th>
                                                    <th>房间数</th>
                                                    <th>收入(元)</th>
                                                </tr>
                                            </thead>
                                            <tbody>
                                                <?php foreach ($day['channels'] as $channel): ?>
                                                    <?php if ($channel['order_count'] > 0): ?>
                                                        <tr>
                                                            <td><?php echo $channel['name']; ?></td>
                                                            <td><?php echo $channel['order_count']; ?></td>
                                                            <td><?php echo $channel['room_count']; ?></td>
                                                            <td><?php echo number_format($channel['revenue'], 2); ?></td>
                                                        </tr>
                                                    <?php endif; ?>
                                                <?php endforeach; ?>
                                            </tbody>
                                        </table>
                                    </td>
                                </tr>
                            <?php endif; ?>
                        <?php endforeach; ?>
                        <?php if (count($daily_stats) == 0): ?>
                            <tr>
                                <td colspan="6" class="text-center">暂无每日订单数据</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 房型订单分析 -->
            <h3>房型订单分析</h3>
            <div class="data-list">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>房型</th>
                            <th>订单数</th>
                            <th>订单占比</th>
                            <th>房间数</th>
                            <th>收入(元)</th>
                            <th>收入占比</th>
                            <th>平均房价(元)</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($room_type_stats as $stat): ?>
                            <tr>
                                <td><?php echo $stat['type_name']; ?></td>
                                <td><?php echo $stat['order_count']; ?></td>
                                <td>
                                    <?php echo $stat['order_percentage']; ?>%
                                    <div class="progress-bar">
                                        <div class="progress-bar-fill" style="width: <?php echo $stat['order_percentage']; ?>%;">
                                            <?php echo $stat['order_percentage']; ?>%
                                        </div>
                                    </div>
                                </td>
                                <td><?php echo $stat['room_count']; ?></td>
                                <td><?php echo number_format($stat['revenue'], 2); ?></td>
                                <td>
                                    <?php echo $stat['revenue_percentage']; ?>%
                                    <div class="progress-bar">
                                        <div class="progress-bar-fill" style="width: <?php echo $stat['revenue_percentage']; ?>%;">
                                            <?php echo $stat['revenue_percentage']; ?>%
                                        </div>
                                    </div>
                                </td>
                                <td><?php echo number_format($stat['avg_rate'], 2); ?></td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (count($room_type_stats) == 0): ?>
                            <tr>
                                <td colspan="7" class="text-center">暂无房型订单数据</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 订单状态分析 -->
            <h3>订单状态分析</h3>
            <div class="data-list">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>订单状态</th>
                            <th>订单数</th>
                            <th>占比</th>
                            <th>房间数</th>
                            <th>收入(元)</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($status_stats as $stat): ?>
                            <tr>
                                <td><?php echo $stat['status_name']; ?></td>
                                <td><?php echo $stat['order_count']; ?></td>
                                <td>
                                    <?php echo $stat['order_percentage']; ?>%
                                    <div class="progress-bar">
                                        <div class="progress-bar-fill <?php
                                                                        echo $stat['status'] == 0 ? 'cancel-rate-high' : 'cancel-rate-low';
                                                                        ?>" style="width: <?php echo $stat['order_percentage']; ?>%;">
                                            <?php echo $stat['order_percentage']; ?>%
                                        </div>
                                    </div>
                                </td>
                                <td><?php echo $stat['room_count']; ?></td>
                                <td><?php echo number_format($stat['revenue'], 2); ?></td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (count($status_stats) == 0): ?>
                            <tr>
                                <td colspan="5" class="text-center">暂无订单状态数据</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <script>
        function updateDateRange() {
            var dateRange = document.getElementById('date_range').value;
            var customDateDiv = document.getElementById('custom_date');
            var customDateEndDiv = document.getElementById('custom_date_end');

            if (dateRange === 'custom') {
                customDateDiv.style.display = '';
                customDateEndDiv.style.display = '';
            } else {
                customDateDiv.style.display = 'none';
                customDateEndDiv.style.display = 'none';
            }
        }

        function toggleChannelDetails(date) {
            var detailsRow = document.getElementById('channel-details-' + date);
            if (detailsRow.style.display === 'none') {
                detailsRow.style.display = 'table-row';
            } else {
                detailsRow.style.display = 'none';
            }
        }
    </script>
</body>

</html>