<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('system');

// 记录访问日志
record_log('访问多语言设置页面');

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加语言
    if ($_POST['action'] == 'add') {
        $code = isset($_POST['code']) ? trim($_POST['code']) : '';
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $is_default = isset($_POST['is_default']) ? 1 : 0;

        if (empty($code) || empty($name)) {
            $error = '语言代码和名称不能为空！';
        } else {
            try {
                // 检查语言代码是否已存在
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM languages WHERE code = ?");
                $stmt->execute([$code]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '语言代码已存在！';
                } else {
                    // 如果设为默认，先将所有语言设为非默认
                    if ($is_default) {
                        $stmt = $pdo->query("UPDATE languages SET is_default = 0");
                    }

                    // 添加语言
                    $stmt = $pdo->prepare("INSERT INTO languages (code, name, is_default, status) VALUES (?, ?, ?, 1)");
                    $result = $stmt->execute([$code, $name, $is_default]);

                    if ($result) {
                        record_log("添加语言：{$name}");
                        $success = '语言添加成功！';
                    } else {
                        $error = '语言添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
    // 编辑语言
    elseif ($_POST['action'] == 'edit') {
        $id = isset($_POST['id']) ? intval($_POST['id']) : 0;
        $code = isset($_POST['code']) ? trim($_POST['code']) : '';
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $is_default = isset($_POST['is_default']) ? 1 : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($id <= 0 || empty($code) || empty($name)) {
            $error = '请填写完整语言信息！';
        } else {
            try {
                // 检查语言代码是否已被其他语言使用
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM languages WHERE code = ? AND id != ?");
                $stmt->execute([$code, $id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '语言代码已被其他语言使用！';
                } else {
                    // 如果设为默认，先将所有语言设为非默认
                    if ($is_default) {
                        $stmt = $pdo->query("UPDATE languages SET is_default = 0");
                    }

                    // 更新语言
                    $stmt = $pdo->prepare("UPDATE languages SET code = ?, name = ?, is_default = ?, status = ? WHERE id = ?");
                    $result = $stmt->execute([$code, $name, $is_default, $status, $id]);

                    if ($result) {
                        record_log("编辑语言：{$name}");
                        $success = '语言更新成功！';
                    } else {
                        $error = '语言更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
    // 删除语言
    elseif ($_POST['action'] == 'delete') {
        $id = isset($_POST['id']) ? intval($_POST['id']) : 0;

        if ($id <= 0) {
            $error = '无效的语言ID！';
        } else {
            try {
                // 检查是否为默认语言
                $stmt = $pdo->prepare("SELECT is_default, name FROM languages WHERE id = ?");
                $stmt->execute([$id]);
                $language = $stmt->fetch();

                if (!$language) {
                    $error = '语言不存在！';
                } elseif ($language['is_default'] == 1) {
                    $error = '默认语言不能删除！';
                } else {
                    // 删除语言
                    $stmt = $pdo->prepare("DELETE FROM languages WHERE id = ?");
                    $result = $stmt->execute([$id]);

                    if ($result) {
                        record_log("删除语言：{$language['name']}");
                        $success = '语言删除成功！';
                    } else {
                        $error = '语言删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
    // 设置默认语言
    elseif ($_POST['action'] == 'set_default') {
        $id = isset($_POST['id']) ? intval($_POST['id']) : 0;

        if ($id <= 0) {
            $error = '无效的语言ID！';
        } else {
            try {
                // 先将所有语言设为非默认
                $stmt = $pdo->query("UPDATE languages SET is_default = 0");

                // 设置指定语言为默认
                $stmt = $pdo->prepare("UPDATE languages SET is_default = 1 WHERE id = ?");
                $result = $stmt->execute([$id]);

                // 获取语言名称，用于日志记录
                $stmt = $pdo->prepare("SELECT name FROM languages WHERE id = ?");
                $stmt->execute([$id]);
                $language = $stmt->fetch();

                if ($result) {
                    record_log("设置默认语言：{$language['name']}");
                    $success = '默认语言设置成功！';
                } else {
                    $error = '默认语言设置失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
    // 切换语言状态
    elseif ($_POST['action'] == 'toggle_status') {
        $id = isset($_POST['id']) ? intval($_POST['id']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 0;

        if ($id <= 0) {
            $error = '无效的语言ID！';
        } else {
            try {
                // 获取语言信息，用于检查和日志记录
                $stmt = $pdo->prepare("SELECT name, is_default FROM languages WHERE id = ?");
                $stmt->execute([$id]);
                $language = $stmt->fetch();

                if (!$language) {
                    $error = '语言不存在！';
                } elseif ($language['is_default'] == 1 && $status == 0) {
                    $error = '默认语言不能禁用！';
                } else {
                    // 更新语言状态
                    $stmt = $pdo->prepare("UPDATE languages SET status = ? WHERE id = ?");
                    $result = $stmt->execute([$status, $id]);

                    $action = $status == 1 ? '启用' : '禁用';
                    if ($result) {
                        record_log("{$action}语言：{$language['name']}");
                        $success = "语言{$action}成功！";
                    } else {
                        $error = "语言{$action}失败！";
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有语言
try {
    $stmt = $pdo->query("SELECT * FROM languages ORDER BY is_default DESC, name");
    $languages = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取语言列表失败：' . $e->getMessage();
    $languages = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>多语言设置</h2>
            <div class="breadcrumb">
                <a href="index.php">系统设置</a> &gt; 多语言设置
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <button class="btn btn-primary" onclick="showAddForm()">添加语言</button>
            </div>

            <!-- 添加语言表单 -->
            <div id="addLanguageForm" class="form-container" style="display: none;">
                <h3>添加语言</h3>
                <form method="post" action="">
                    <input type="hidden" name="action" value="add">

                    <div class="form-group">
                        <label for="code">语言代码：</label>
                        <input type="text" id="code" name="code" required placeholder="例如：en-US">
                    </div>

                    <div class="form-group">
                        <label for="name">语言名称：</label>
                        <input type="text" id="name" name="name" required placeholder="例如：English">
                    </div>

                    <div class="form-group">
                        <label>
                            <input type="checkbox" name="is_default" value="1">
                            设为默认语言
                        </label>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-success">保存</button>
                        <button type="button" class="btn btn-secondary" onclick="hideAddForm()">取消</button>
                    </div>
                </form>
            </div>

            <!-- 编辑语言表单 -->
            <div id="editLanguageForm" class="form-container" style="display: none;">
                <h3>编辑语言</h3>
                <form method="post" action="">
                    <input type="hidden" name="action" value="edit">
                    <input type="hidden" name="id" id="edit_language_id">

                    <div class="form-group">
                        <label for="edit_code">语言代码：</label>
                        <input type="text" id="edit_code" name="code" required>
                    </div>

                    <div class="form-group">
                        <label for="edit_name">语言名称：</label>
                        <input type="text" id="edit_name" name="name" required>
                    </div>

                    <div class="form-group">
                        <label>
                            <input type="checkbox" name="is_default" id="edit_is_default" value="1">
                            设为默认语言
                        </label>
                    </div>

                    <div class="form-group">
                        <label>状态：</label>
                        <select name="status" id="edit_status">
                            <option value="1">启用</option>
                            <option value="0">禁用</option>
                        </select>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-success">保存</button>
                        <button type="button" class="btn btn-secondary" onclick="hideEditForm()">取消</button>
                    </div>
                </form>
            </div>

            <!-- 语言列表 -->
            <div class="table-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>语言代码</th>
                            <th>语言名称</th>
                            <th>默认语言</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($languages)): ?>
                            <tr>
                                <td colspan="6" class="text-center">暂无语言数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($languages as $lang): ?>
                                <tr>
                                    <td><?php echo $lang['id']; ?></td>
                                    <td><?php echo htmlspecialchars($lang['code']); ?></td>
                                    <td><?php echo htmlspecialchars($lang['name']); ?></td>
                                    <td>
                                        <?php if ($lang['is_default'] == 1): ?>
                                            <span class="status-active">是</span>
                                        <?php else: ?>
                                            <span class="status-inactive">否</span>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <?php if ($lang['status'] == 1): ?>
                                            <span class="status-active">启用</span>
                                        <?php else: ?>
                                            <span class="status-inactive">禁用</span>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <button class="btn btn-sm btn-primary" onclick="editLanguage(<?php echo $lang['id']; ?>, '<?php echo htmlspecialchars($lang['code']); ?>', '<?php echo htmlspecialchars($lang['name']); ?>', <?php echo $lang['is_default']; ?>, <?php echo $lang['status']; ?>)">编辑</button>
                                        <?php if ($lang['is_default'] != 1): // 防止删除默认语言 
                                        ?>
                                            <button class="btn btn-sm btn-danger" onclick="deleteLanguage(<?php echo $lang['id']; ?>, '<?php echo htmlspecialchars($lang['name']); ?>')">删除</button>
                                        <?php endif; ?>
                                        <?php if ($lang['is_default'] != 1): // 非默认语言可设为默认 
                                        ?>
                                            <button class="btn btn-sm btn-success" onclick="setDefault(<?php echo $lang['id']; ?>, '<?php echo htmlspecialchars($lang['name']); ?>')">设为默认</button>
                                        <?php endif; ?>
                                        <?php if ($lang['status'] == 1 && $lang['is_default'] != 1): // 已启用非默认语言可禁用 
                                        ?>
                                            <button class="btn btn-sm btn-warning" onclick="toggleStatus(<?php echo $lang['id']; ?>, 0, '<?php echo htmlspecialchars($lang['name']); ?>')">禁用</button>
                                        <?php elseif ($lang['status'] == 0): // 已禁用状态可启用 
                                        ?>
                                            <button class="btn btn-sm btn-info" onclick="toggleStatus(<?php echo $lang['id']; ?>, 1, '<?php echo htmlspecialchars($lang['name']); ?>')">启用</button>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 删除语言表单 -->
            <form id="deleteLanguageForm" method="post" action="" style="display: none;">
                <input type="hidden" name="action" value="delete">
                <input type="hidden" name="id" id="delete_language_id">
            </form>

            <!-- 设为默认语言表单 -->
            <form id="setDefaultForm" method="post" action="" style="display: none;">
                <input type="hidden" name="action" value="set_default">
                <input type="hidden" name="id" id="default_language_id">
            </form>

            <!-- 切换状态表单 -->
            <form id="toggleStatusForm" method="post" action="" style="display: none;">
                <input type="hidden" name="action" value="toggle_status">
                <input type="hidden" name="id" id="toggle_status_id">
                <input type="hidden" name="status" id="toggle_status_value">
            </form>
        </div>
    </div>

    <script>
        // 显示添加语言表单
        function showAddForm() {
            document.getElementById('addLanguageForm').style.display = 'block';
            document.getElementById('editLanguageForm').style.display = 'none';
        }

        // 隐藏添加语言表单
        function hideAddForm() {
            document.getElementById('addLanguageForm').style.display = 'none';
        }

        // 显示编辑语言表单
        function editLanguage(id, code, name, isDefault, status) {
            document.getElementById('edit_language_id').value = id;
            document.getElementById('edit_code').value = code;
            document.getElementById('edit_name').value = name;
            document.getElementById('edit_is_default').checked = isDefault == 1;
            document.getElementById('edit_status').value = status;

            document.getElementById('editLanguageForm').style.display = 'block';
            document.getElementById('addLanguageForm').style.display = 'none';
        }

        // 隐藏编辑语言表单
        function hideEditForm() {
            document.getElementById('editLanguageForm').style.display = 'none';
        }

        // 删除语言
        function deleteLanguage(id, name) {
            if (confirm('确定要删除语言 "' + name + '" 吗？')) {
                document.getElementById('delete_language_id').value = id;
                document.getElementById('deleteLanguageForm').submit();
            }
        }

        // 设为默认语言
        function setDefault(id, name) {
            if (confirm('确定将 "' + name + '" 设为默认语言吗？')) {
                document.getElementById('default_language_id').value = id;
                document.getElementById('setDefaultForm').submit();
            }
        }

        // 切换语言状态
        function toggleStatus(id, status, name) {
            var action = status == 1 ? '启用' : '禁用';
            if (confirm('确定要' + action + '语言 "' + name + '" 吗？')) {
                document.getElementById('toggle_status_id').value = id;
                document.getElementById('toggle_status_value').value = status;
                document.getElementById('toggleStatusForm').submit();
            }
        }
    </script>
</body>

</html>